@@ -7,7 +7,7 @@ BEGIN {
   $NetPacket::UDP::AUTHORITY = 'cpan:YANICK';
 }
 {
-  $NetPacket::UDP::VERSION = '1.3.3';
+  $NetPacket::UDP::VERSION = '1.4.0';
 }
 # ABSTRACT: Assemble and disassemble UDP (User Datagram Protocol) packets.
 
@@ -83,22 +83,18 @@ sub strip {
 #
 
 sub encode {
-
-    my $self = shift;
-    my ($ip) = @_;
-    my ($packet);
-
-    # Adjust the length accodingly
+    my ($self, $ip) = @_;
+ 
+    # Adjust the length accordingly
     $self->{len} = 8 + length($self->{data});
 
     # First of all, fix the checksum
     $self->checksum($ip);
 
     # Put the packet together
-    $packet = pack("nnnna*", $self->{src_port},$self->{dest_port},
+    return pack("nnnna*", $self->{src_port},$self->{dest_port},
                 $self->{len}, $self->{cksum}, $self->{data});
 
-    return($packet); 
 }
 
 # 
@@ -144,14 +140,14 @@ NetPacket::UDP - Assemble and disassemble UDP (User Datagram Protocol) packets.
 
 =head1 VERSION
 
-version 1.3.3
+version 1.4.0
 
 =head1 SYNOPSIS
 
   use NetPacket::UDP;
 
   $udp_obj = NetPacket::UDP->decode($raw_pkt);
-  $udp_pkt = NetPacket::UDP->encode($ip_obj);
+  $udp_pkt = $udp_obj->encode($l3_obj);
   $udp_data = NetPacket::UDP::strip($raw_pkt);
 
 =head1 DESCRIPTION
@@ -170,11 +166,12 @@ instance data.  This method will quite happily decode garbage input.
 It is the responsibility of the programmer to ensure valid packet data
 is passed to this method.
 
-=item C<NetPacket::UDP-E<gt>encode($ip_obj)>
+=item C<$udp_packet-<gt>encode($l3_obj)>
 
-Return a UDP packet encoded with the instance data specified. Needs parts 
-of the IP header contained in $ip_obj, the IP object, in order to calculate 
-the UDP checksum. The length field will also be set automatically.
+Return the encoded version of the UDP packet object. Needs
+part of the IP header contained (src_ip and dest_ip specifically) in $l3_obj, 
+in order to calculate the UDP checksum. The length field will also be set 
+automatically based on values provided.
 
 =back
 
@@ -223,6 +220,24 @@ The encapsulated data (payload) for this packet.
 
 =back
 
+=head2 IP data
+
+The IP data for the $l3_obj object consists of the following fields.
+Additional items may be supplied as well as passing the whole
+object returned by NetPacket::IP->decode but are unnecessary.
+
+=over
+
+=item src_ip
+
+The source IP for the datagram
+
+=item dest_ip
+
+The destination IP for the datagram
+
+=back
+
 =head2 Exports
 
 =over
@@ -307,7 +322,7 @@ netcat, but otherwise makes little sense. :) Adapt to your needs:
             $udp_obj->{data} =~ s/foo/bar/g;
 
             # reencode the packet
-            $ip_obj->{data} = $udp_obj->encode($ip_obj);
+            $ip_obj->{data} = $udp_obj->encode($udp_obj, $ip_obj);
             $data = $ip_obj->encode;
 
         }
